Learn R Programming

cookiemonster (version 0.1.0)

get_cookies_from_browser: Get Cookies from Browser

Description

Retrieves all cookies from a Browser (currently works with Firefox only).

Usage

get_cookies_from_browser(browser = "Firefox")

Value

A tibble containing the cookies from the specified browser.

Arguments

browser

A character string specifying the browser to get cookies from. Defaults to "Firefox".

Examples

Run this code
if (FALSE) {
get_cookies_from_browser("Firefox")
}

Run the code above in your browser using DataLab